diff --git a/osu.Game/Rulesets/Scoring/HitResult.cs b/osu.Game/Rulesets/Scoring/HitResult.cs
index 370ffb3a7f..1de62cf8e5 100644
--- a/osu.Game/Rulesets/Scoring/HitResult.cs
+++ b/osu.Game/Rulesets/Scoring/HitResult.cs
@@ -100,7 +100,7 @@ namespace osu.Game.Rulesets.Scoring
public static class HitResultExtensions
{
///
- /// Whether a affects the combo.
+ /// Whether a increases/decreases the combo, and affects the combo portion of the score.
///
public static bool AffectsCombo(this HitResult result)
{
@@ -122,12 +122,14 @@ namespace osu.Game.Rulesets.Scoring
}
///
- /// Whether a should be counted as combo score.
+ /// Whether a affects the accuracy portion of the score.
+ ///
+ public static bool AffectsAccuracy(this HitResult result)
+ => IsScorable(result) && !IsBonus(result);
+
+ ///
+ /// Whether a should be counted as bonus score.
///
- ///
- /// This is not the reciprocal of , as and do not affect combo
- /// but are still considered as part of the accuracy (not bonus) portion of the score.
- ///
public static bool IsBonus(this HitResult result)
{
switch (result)